==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiWidgets/QGraphicsScale_shell.h <==
#ifndef QGRAPHICSSCALE_SHELL_H
#define QGRAPHICSSCALE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicstransform.h>
#endif //QT_CONFIG(graphicsview)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qmatrix4x4.h>
#include <QtGui/qvector3d.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(graphicsview)

class QGraphicsScale_shell : public QGraphicsScale, public QtJambiShellInterface
{
public:
    QGraphicsScale_shell(QObject* parent0 = nullptr);
    ~QGraphicsScale_shell() override;

    void applyTo(QMatrix4x4* matrix0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsScale_access : public QGraphicsScale
{
    void __qt_applyTo_QMatrix4x4_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID matrix0) const;
};

#endif // QT_CONFIG(graphicsview)
#endif // QGRAPHICSSCALE_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiWidgets/QGraphicsScale_shell.h <==
#ifndef QGRAPHICSSCALE_SHELL_H
#define QGRAPHICSSCALE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicstransform.h>
#endif //QT_CONFIG(graphicsview)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qmatrix4x4.h>
#include <QtGui/qvectornd.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(graphicsview)

class QGraphicsScale_shell : public QGraphicsScale, public QtJambiShellInterface
{
public:
    QGraphicsScale_shell(QObject* parent0 = nullptr);
    ~QGraphicsScale_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QGraphicsScale_mshell;
    friend class QGraphicsScale_oshell;
};


class QGraphicsScale_mshell : public QGraphicsScale_shell
{
public:
    using QGraphicsScale_shell::QGraphicsScale_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QGraphicsScale_oshell : public QGraphicsScale_mshell
{
public:
    using QGraphicsScale_mshell::QGraphicsScale_mshell;
    void applyTo(QMatrix4x4* matrix0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsScale_access : public QGraphicsScale
{
    void __qt_applyTo_QMatrix4x4_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID matrix0) const;
};

#endif // QT_CONFIG(graphicsview)
#endif // QGRAPHICSSCALE_SHELL_H
